{  This program demonstrates the work of TSpywareScanner component.

   In this sample you can see all its key features:
    - Processes' scanning
    - Scanning of the autorun's keys
    - Scanning for malicious BHO's
    - Files' scanning

   User can specify pathes, keys and other parameters of scanning with the
   visual controls of the form.

   Component searches for malicious software using database provided. Found programs
   can be deleted. User can choose whether to delete all found malware or ask
   user what to do each time something is found.

   Please note that malware database which is supplied with this sample is a sample as well.
   Real database contains more than 6000 spyware, adware and other types of malicious programs.
   We'll send you this database upon registration.

 Homepage: http://www.QwertyStudios.com/tss/product.html
 Support: mailto:support@qwertystudios.com
 Buy Buy TSpywareScanner now: http://store.esellerate.net/s.asp?s=STR6130735119&Cmd=BUY&SKURefnum=SKU54316466540
 Buy TSpywareScanner with sources now: http://store.esellerate.net/s.asp?s=STR6130735119&Cmd=BUY&SKURefnum=SKU59698355038
 Copyright (C) 2005 QwertyStudios
}

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, SpywareScanner, Spyware, ComCtrls;

type
  TMainForm = class(TForm)
    Results: TMemo;
    Scan: TButton;
    Cancel: TButton;
    Pathes: TMemo;
    Label1: TLabel;
    Label2: TLabel;
    Keys: TMemo;
    Label3: TLabel;
    SpywareScanner: TSpywareScanner;
    Progress: TProgressBar;
    FixFounded: TCheckBox;
    StatusBar: TStatusBar;
    Label4: TLabel;
    Extensions: TMemo;
    ExtensionsSet: TComboBox;
    procedure ScanClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure SpywareScannerScanningComplete(Sender: TObject);
    procedure SpywareScannerFoundBHO(Sender: TObject; Spyware: TSpyware;
      Key: string; var Fix: Boolean);
    procedure SpywareScannerFoundInAutorun(Sender: TObject;
      Spyware: TSpyware; RootKey: HKEY; Path, Value, FileName: string;
      var Fix: Boolean);
    procedure SpywareScannerFoundInProcesses(Sender: TObject;
      Spyware: TSpyware; FileName: string; var Fix: Boolean);
    procedure SpywareScannerProgressFileScanning(Sender: TObject;
      CurrentFilesCount, AllFilesCount: Int64);
    procedure CancelClick(Sender: TObject);
    procedure SpywareScannerGotFilesCount(Sender: TObject;
      FilesCount: Int64);
    procedure SpywareScannerFoundInFiles(Sender: TObject;
      Spyware: TSpyware; Path, FileName: string; var Fix: Boolean);
    procedure ExtensionsSetChange(Sender: TObject);
    procedure SpywareScannerProgressFileCounting(Sender: TObject;
      CurrentFilePath: string);
    procedure SpywareScannerFixingError(Sender: TObject; Spyware: TSpyware;
      FixingError: TFixingErrorType);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

procedure TMainForm.ScanClick(Sender: TObject);
begin

  //Disable scan button
  Scan.Enabled := false;
  //Enable cancel button
  Cancel.Enabled := true;
  // Reset progress bar
  Progress.Position := 0;

  // Clear results' field
  Results.Clear;

  // Reset pathes, keys of scanning and files' extensions
  SpywareScanner.Pathes.Clear;
  SpywareScanner.AutorunKeys.Clear;
  SpywareScanner.Extensions.Clear;

  SpywareScanner.Pathes.AddStrings(Pathes.Lines);
  SpywareScanner.AutorunKeys.AddStrings(Keys.Lines);
  SpywareScanner.Extensions.AddStrings(Extensions.Lines);

  // Scan processes
  StatusBar.SimpleText := 'Scanning processes...';
  SpywareScanner.ScanProcesses;

  // Scan autorun keys
  StatusBar.SimpleText := 'Scanning autorun keys...';
  SpywareScanner.ScanAutorun;

  // Scan for BHO
  StatusBar.SimpleText := 'Scanning BHOs...';
  SpywareScanner.ScanBHO;

  // Preparing for files' scanning. Get files count.
  SpywareScanner.GetFilesCount;
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  //Load database of mailware from the file. Database is encrypted with key 'utgnujtenbjujednfjdnjvnbujenuifn'.
  SpywareScanner.LoadDBFromFile(ExtractFilePath(Application.ExeName) + 'db.dat', 'utgnujtenbjujednfjdnjvnbujenuifn');
  // Set the path where TSpywareScanner copies backups of deleted files
  SpywareScanner.BackupFilesPath := ExtractFilePath(Application.ExeName) + '\infected\';
end;

procedure TMainForm.SpywareScannerScanningComplete(Sender: TObject);
begin
  StatusBar.SimpleText := '';

  //Enable scan button
  Scan.Enabled := true;

  //Disable cancel button
  Cancel.Enabled := false;

  StatusBar.SimpleText := 'Scanning completed';
  Progress.Position := 0;
end;

procedure TMainForm.SpywareScannerFoundBHO(Sender: TObject;
  Spyware: TSpyware; Key: string; var Fix: Boolean);
begin
  // Add information about found BHO to results' field
  Results.Lines.Add('Malicious BHO ' + Key + ' is found');

  // Handle spyware deletion
  Fix := false;
  if FixFounded.Checked then
    Fix := true
  else
  begin
    if MessageDlg('Do you want to delete this spyware?', mtWarning, [mbYes, mbNo], 0) = mrYes then
      Fix := true;
  end;

  Results.Lines.Add('====================================================');
end;

procedure TMainForm.SpywareScannerFoundInAutorun(Sender: TObject;
  Spyware: TSpyware; RootKey: HKEY; Path, Value, FileName: string;
  var Fix: Boolean);
begin
  // Add the information about found spyware into results' field
  Results.Lines.Add('Spyware ' + FileName + ' is found'
    + ' in registry at key ' + Path + ' with value ' + Value);

  // Handle spyware deletion
  Fix := false;
  if FixFounded.Checked then
    Fix := true
  else
  begin
    if MessageDlg('Do you want to delete this spyware?', mtWarning, [mbYes, mbNo], 0) = mrYes then
      Fix := true;
  end;

  Results.Lines.Add('====================================================');
end;

procedure TMainForm.SpywareScannerFoundInProcesses(Sender: TObject;
  Spyware: TSpyware; FileName: string; var Fix: Boolean);
begin
  // Add the information about found spyware into results' field
  Results.Lines.Add('Spyware ' + FileName + ' is found'
    + ' in process ' + FileName);

  // Handle spyware deletion
  Fix := false;
  if FixFounded.Checked then
    Fix := true
  else
  begin
    if MessageDlg('Do you want to delete this spyware?', mtWarning, [mbYes, mbNo], 0) = mrYes then
      Fix := true;
  end;

  Results.Lines.Add('====================================================');
end;

procedure TMainForm.SpywareScannerProgressFileScanning(Sender: TObject;
  CurrentFilesCount, AllFilesCount: Int64);
begin
  // Set progress bar's position
  Progress.Position := Round(CurrentFilesCount / AllFilesCount * 100);
end;

procedure TMainForm.CancelClick(Sender: TObject);
begin
  // Abort files' scanning
  SpywareScanner.AbortFileScanning;

  Scan.Enabled := true;
  Cancel.Enabled := false;
  StatusBar.SimpleText := 'Scanning canceled';

  Progress.Position := 0;
end;

procedure TMainForm.SpywareScannerGotFilesCount(Sender: TObject;
  FilesCount: Int64);
begin
  // Show how many files are to be scanned and start files' scanning
  ShowMessage('Files to be scanned ' + IntToStr(FilesCount));

  StatusBar.SimpleText := 'Scanning files...';
  SpywareScanner.ScanFiles;
end;

procedure TMainForm.SpywareScannerFoundInFiles(Sender: TObject;
  Spyware: TSpyware; Path, FileName: string; var Fix: Boolean);
begin
  // Add ithe nformation about found spyware into results' field
  Results.Lines.Add('Spyware ' + FileName + ' is found'
    + ' in ' + Path);

  // Handle spyware deletion
  Fix := false;
  if FixFounded.Checked then
    Fix := true
  else
  begin
    if MessageDlg('Do you want to delete this spyware?', mtWarning, [mbYes, mbNo], 0) = mrYes then
      Fix := true;
  end;

  Results.Lines.Add('====================================================');
end;

procedure TMainForm.ExtensionsSetChange(Sender: TObject);
begin
  if ExtensionsSet.ItemIndex = 0 then
  begin
    Extensions.Clear;

    Extensions.Lines.Add('exe');
    Extensions.Lines.Add('pif');
    Extensions.Lines.Add('vbs');
    Extensions.Lines.Add('dll');
    Extensions.Lines.Add('com');
    Extensions.Lines.Add('js');
    Extensions.Lines.Add('bat');
    Extensions.Lines.Add('hta');
  end;

  if ExtensionsSet.ItemIndex = 1 then
  begin
    Extensions.Clear;

    Extensions.Lines.Add('*');
  end;
end;

procedure TMainForm.SpywareScannerProgressFileCounting(Sender: TObject;
  CurrentFilePath: string);
begin
  StatusBar.SimpleText := 'Calculating files count... ' + CurrentFilePath;
end;

procedure TMainForm.SpywareScannerFixingError(Sender: TObject;
  Spyware: TSpyware; FixingError: TFixingErrorType);
var
  SpywareInProcesses: TSpywareInProcesses;
  SpywareInFiles: TSpywareInFiles;
  SpywareInAutorun: TSpywareInAutorun;
  SpywareInBHO: TSpywareInBHO;
begin
  if FixingError = processesFixing then
  begin
    SpywareInProcesses := TSpywareInProcesses(Spyware);

    ShowMessage('Error in process deletion: ' + SpywareInProcesses.Msg);
  end;

  if FixingError = fileFixing then
  begin
    SpywareInFiles := TSpywareInFiles(Spyware);

    ShowMessage('Error in file deletion: ' + SpywareInFiles.FilePath + '\' + SpywareInFiles.Msg);
  end;

  if FixingError = autorunFixing then
  begin
    SpywareInAutorun := TSpywareInAutorun(Spyware);

    ShowMessage('Error in autroun list member deletion: ' + SpywareInAutorun.Msg);
  end;

  if FixingError = bhoFixing then
  begin
    SpywareInBHO := TSpywareInBHO(Spyware);

    ShowMessage('Error in BHO deletion: ' + SpywareInBHO.Msg);
  end;
end;

end.

